/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package photostrip;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.GridLayout;
import java.awt.RenderingHints;
import java.io.IOException;
import java.net.URL;
import java.security.AccessControlException;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.JComponent;
import javax.swing.SwingUtilities;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.xpath.XPathExpressionException;
import org.xml.sax.SAXException;

/**
 *
 * @author joshy
 */
public class PhotoStrip extends JComponent {
    private String feedURL;
    private List<PhotoResource> photos;
    private int size;
    private String errorMessage = null;
    private URLShower shower;
    private int rows;
    private int cols;

    public PhotoStrip(String feedURL, int cols, int rows, int size, URLShower shower) {
        this.shower = shower;
        this.feedURL = feedURL;
        this.size = size;
        this.rows = rows;
        this.cols = cols;
        setPreferredSize(new Dimension(cols*size, rows*size));
        this.setLayout(new GridLayout(rows,cols));
        setBackground(Color.BLACK);
        worker.start();
    }
    
    private Thread worker = new Thread(new Runnable() {
        public void run() {
            try {
                final List<PhotoResource> photos = PhotoStream.parse(new URL(feedURL));
                SwingUtilities.invokeLater(new Runnable() {
                    public void run() {
                        setPhotos(photos);
                    }
                });
            } catch (ParserConfigurationException ex) {
                Logger.getLogger(PhotoStrip.class.getName()).log(Level.SEVERE, null, ex);
            } catch (SAXException ex) {
                Logger.getLogger(PhotoStrip.class.getName()).log(Level.SEVERE, null, ex);
            } catch (XPathExpressionException ex) {
                Logger.getLogger(PhotoStrip.class.getName()).log(Level.SEVERE, null, ex);
            } catch (IOException ex) {
                Logger.getLogger(PhotoStrip.class.getName()).log(Level.SEVERE, null, ex);
            } catch (AccessControlException ex) {
                p("couldn't access flickr. probably on an older jre");
                setErrorMessage("Couldn't connect to Flickr. Access denied.",ex);
                //Logger.getLogger(PhotoStrip.class.getName()).log(Level.SEVERE, null, ex);
            }
        }

    });

    private void p(String string) {
        System.out.println(string);
    }


    private void setPhotos(List<PhotoResource> photos) {
        this.photos = photos;
        for(int i=0; i<rows*cols && i < photos.size(); i++) {
            PhotoResource photo = photos.get(i);
            addPhoto(photo);
        }
        repaint();
    }
    
    private void addPhoto(final PhotoResource photo) {
        add(new PhotoView(photo, size, shower));
        repaint();
        revalidate();
    }
    
    private void setErrorMessage(String string, AccessControlException ex) {
        this.errorMessage = string;
        repaint();
    }

    /*
    @Override
    protected void paintComponent(Graphics gfx) {
        super.paintComponent(gfx);
        Graphics2D g = (Graphics2D) gfx;
        g.setRenderingHint(RenderingHints.KEY_INTERPOLATION, RenderingHints.VALUE_INTERPOLATION_BICUBIC);
        if(errorMessage != null) {
            g.setColor(getBackground());
            g.fillRect(0, 0, getWidth(), getHeight());
            g.setColor(Color.WHITE);
            g.drawString(errorMessage, 20, 20);
        }
    }*/
}
