/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package photostrip;

import java.awt.Graphics;
import java.awt.GraphicsConfiguration;
import java.awt.GraphicsDevice;
import java.awt.GraphicsEnvironment;
import java.awt.Transparency;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.imageio.ImageIO;
import javax.swing.SwingUtilities;

/**
 *
 * @author joshy
 */
public class PhotoResource {

    private String url;
    private ActionListener listener;
    private BufferedImage img;
    private boolean isLoaded = false;
    private String pageURL;

    public PhotoResource(String url, String pageURL) {
        this.url = url;
        this.pageURL = pageURL;
    }

    public void setCallback(ActionListener actionListener) {
        this.listener = actionListener;
    }

    public BufferedImage getImage() {
        return img;
    }

    public String getPageURL() {
        return this.pageURL;
    }

    public synchronized boolean isLoaded() {
        return isLoaded;
    }

    private synchronized void setLoaded(boolean loaded) {
        this.isLoaded = loaded;
    }

    private void alertCallback() {
        SwingUtilities.invokeLater(new Runnable() {

            public void run() {
                if (listener != null) {
                    listener.actionPerformed(new ActionEvent(PhotoResource.this, -1, "loaded") {

                        @Override
                        public String paramString() {
                            return url;
                        }
                    });
                }
            }
        });
    }

    void startLoading() {
        new Thread(new Runnable() {

            public void run() {
                try {
                    img = ImageIO.read(new URL(url));
                    img = toCompatibleImage(img);
                    setLoaded(true);
                    alertCallback();
                } catch (MalformedURLException ex) {
                    Logger.getLogger(PhotoResource.class.getName()).log(Level.SEVERE, null, ex);
                } catch (IOException ex) {
                    Logger.getLogger(PhotoResource.class.getName()).log(Level.SEVERE, null, ex);
                }
            }
        }).start();
    }

    private static GraphicsConfiguration configuration = GraphicsEnvironment.getLocalGraphicsEnvironment().getDefaultScreenDevice().getDefaultConfiguration();
    
    public static BufferedImage toCompatibleImage(BufferedImage image) {
        BufferedImage compatibleImage = configuration.createCompatibleImage(image.getWidth(),
                image.getHeight(), Transparency.TRANSLUCENT);
        Graphics g = compatibleImage.getGraphics();
        g.drawImage(image, 0, 0, null);
        g.dispose();
        return compatibleImage;
    }
    
    private static BufferedImage createCompatibleImage(int width, int height) {
        GraphicsEnvironment environment =
                GraphicsEnvironment.getLocalGraphicsEnvironment();
        GraphicsDevice screenDevice = environment.getDefaultScreenDevice();
        GraphicsConfiguration configuration =
                screenDevice.getDefaultConfiguration();
        return configuration.createCompatibleImage(width, height);
    }
}
