/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package photostrip;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.RenderingHints;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseEvent;
import java.awt.image.BufferedImage;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.JComponent;
import javax.swing.event.MouseInputAdapter;
import javax.swing.event.MouseInputListener;

/**
 *
 * @author joshy
 */
public class PhotoView extends JComponent {
    private int size;
    private PhotoResource photo;
    private boolean highlight = false;

    public PhotoView(final PhotoResource photo, int size, final URLShower shower) {
        this.size = size;
        this.photo = photo;
        photo.setCallback(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                System.out.println("done loading: " + e.paramString() + " = " + photo.getImage());
                repaint();
            }
        });
        photo.startLoading();
        
         MouseInputListener mouse = new MouseInputAdapter() {
            @Override
            public void mouseClicked(MouseEvent arg0) {
                try {
                    shower.showDocument(new URL(photo.getPageURL()));
                } catch (MalformedURLException ex) {
                    Logger.getLogger(PhotoView.class.getName()).log(Level.SEVERE, null, ex);
                }
            }

            @Override
            public void mouseEntered(MouseEvent arg0) {
                highlight = true;
                repaint();
            }

            @Override
            public void mouseExited(MouseEvent arg0) {
                highlight = false;
                repaint();
            }
            
        };
        
        this.addMouseListener(mouse);
        this.addMouseMotionListener(mouse);
    }

    @Override
    protected void paintComponent(Graphics gfx) {
        super.paintComponent(gfx);
        Graphics2D g = (Graphics2D) gfx;
        g.setRenderingHint(RenderingHints.KEY_INTERPOLATION, RenderingHints.VALUE_INTERPOLATION_BICUBIC);
        
        //draw background
        g.setColor(Color.BLACK);
        g.fillRect(0, 0, getWidth(), getHeight());
        
        
        if(photo.isLoaded()) {
            BufferedImage img = photo.getImage();
            int sx = 0;
            int sy = 0;
            int sw = img.getWidth();
            int sh = img.getHeight();

            if(img.getWidth() > img.getHeight()) {
                int off = img.getWidth()-img.getHeight();
                off = off/2;
                sx+=off;
                sw-=off;
            }
            if(img.getWidth() < img.getHeight()) {
                int off = img.getHeight()-img.getWidth();
                off = off/2;
                sy+=off;
                sh-=off;
            }
            
            g.drawImage(img, 
                    0, 0, size, size,
                    sx,sy,sw,sh,
                    null);
        }
        
        
        if(highlight) {
            g.setColor(new Color(255,255,255,100));
            g.fillRect(1, 1, size-2,size-2);
        }
        
        //draw a border
        g.setColor(Color.GRAY);
        g.drawRect(0,0,size-1,size-1);
        
        
    }
    
    

}
